| Title: | Data and 'Shiny' Application for the Show 'SouthPark' |
|---|---|
| Description: | Ratings, votes, swear words and sentiments are analysed for the show 'SouthPark' through a 'Shiny' application after web scraping from 'IMDB' and the website <https://southpark.fandom.com/wiki/South_Park_Archives>. |
| Authors: | Amalan Mahendran [cre, aut] |
| Maintainer: | Amalan Mahendran <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 1.0.0 |
| Built: | 2026-05-25 10:52:40 UTC |
| Source: | https://github.com/Amalan-ConStat/SouthParkRshiny |
Average rating and votes summarised in different ways.
Basic_plotsBasic_plots
A list with
1Number of Votes vs Average Rating
2Number of episodes in seasons and their runtime
3Average ratings and votes for each season
length(Basic_plots)length(Basic_plots)
Three and four word phrases common among seasons, main characters and supporting characters are summarised through a plot here, from the script data.
N_Grams_plotsN_Grams_plots
A list with
1Three word pharases over seasons
2Four word pharases over seasons
3Three word pharases over main characters
4Four word pharases over main characters
5Three word pharases over supporting characters
6Four word pharases over supporting characters
length(N_Grams_plots)length(N_Grams_plots)
Detailed plots for ratings and votes from the IMDB data.
Ratings_Votes_plotsRatings_Votes_plots
A list with
1Rating for all seasons and episodes
2Votes for all seasons and episodes
length(Ratings_Votes_plots)length(Ratings_Votes_plots)
Run the Shiny Application
run_app(...)run_app(...)
... |
list of golem options. |
used for side effects
Number of positive and negative words based on bing,nrc,loughran among the main four characters per season are summarised through a plot here, from the script data.
Sentiment_Four_plotsSentiment_Four_plots
A list with
1positive words from bing over seasons
2negative words from bing over seasons
3positive words from nrc over seasons
4negative words from nrc over seasons
5positive words from loughran over seasons
6negative words from loughran over seasons
length(Sentiment_Four_plots)length(Sentiment_Four_plots)
Number of positive and negative words based on bing,nrc,loughran among the seasons are summarised through a plot here, from the script data.
Sentiment_General_plotsSentiment_General_plots
A list with
1positive words from bing over seasons
2negative words from bing over seasons
3positive words from nrc over seasons
4negative words from nrc over seasons
5positive words from loughran over seasons
6negative words from loughran over seasons
length(Sentiment_General_plots)length(Sentiment_General_plots)
Number of positive and negative words based on bing,nrc,loughran among the supporting characters per season are summarised through a plot here, from the script data.
Sentiment_Support_plotsSentiment_Support_plots
A list with
1positive words from bing over seasons
2negative words from bing over seasons
3positive words from nrc over seasons
4negative words from nrc over seasons
5positive words from loughran over seasons
6negative words from loughran over seasons
length(Sentiment_Support_plots)length(Sentiment_Support_plots)
SouthPark IMDB Data Data from the IMDB website are extracted for the show. The data consists of season, episode, primarytitle, originaltitle, year, runtime(in minutes), averagerating and number of votes.
SouthPark_IMDB_DataSouthPark_IMDB_Data
A dataframe with
SeasonSeason Number
EpisodeEpisode Number
PrimaryTitleprimary title of the episode
OriginalTitleoriginal title of the episode
Yearyear the episode was aired
Runtimeruntime in minutes
AverageRatingaverage rating out of 10
NumberOfVotesnumber of votes recorded
sort(unique(SouthPark_IMDB_Data$Season)) # the seasons of the show mean(SouthPark_IMDB_Data$AverageRating) # the average rating of the show sum(SouthPark_IMDB_Data$NumberOfVotes) # sum of the number of votessort(unique(SouthPark_IMDB_Data$Season)) # the seasons of the show mean(SouthPark_IMDB_Data$AverageRating) # the average rating of the show sum(SouthPark_IMDB_Data$NumberOfVotes) # sum of the number of votes
Data for the scripts scraped from the website are stored here. The data consists of season, episode, character and line.
SouthPark_Script_DataSouthPark_Script_Data
A dataframe with
SeasonSeason Number
EpisodeEpisode Number
CharacterCharacter Name
LineThe lines the character spoke
unique(SouthPark_Script_Data$Season) # the seasons of the show unique(SouthPark_Script_Data$Character) |> length() # the unique characters in the showunique(SouthPark_Script_Data$Season) # the seasons of the show unique(SouthPark_Script_Data$Character) |> length() # the unique characters in the show
Overall summary plot from the script data.
Southpark_SummarySouthpark_Summary
A dataframe with
Triviatrivial information labels
Valuesdata for the trivial information
Swear word plots for main and supporting characters per seasons. Total number of words and unique words are summarised through plots.
Swear_Words_plotsSwear_Words_plots
A list with
1Swear words in general
2Swear words for main characters
3Swear words for supporting characters
length(Swear_Words_plots)length(Swear_Words_plots)